#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.3.0.0
visibility:           public
id:                   resource-pool-0.3.0.0-8LTOJmgCll57z5bKtmxgMg
key:                  resource-pool-0.3.0.0-8LTOJmgCll57z5bKtmxgMg
license:              BSD-3-Clause
maintainer:           andrzej@rybczak.net
author:               Andrzej Rybczak, Bryan O'\''Sullivan
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  0b635bae1a7fe9abad04535e314a708b
exposed:              True
exposed-modules:      Data.Pool Data.Pool.Internal Data.Pool.Introspection
import-dirs:          /usr/lib/ghc-9.6.6/site-local/resource-pool-0.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/resource-pool-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/resource-pool-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.3.0.0-8LTOJmgCll57z5bKtmxgMg
depends:
    base-4.18.2.1 primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5 time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

